summaryrefslogtreecommitdiffstats
path: root/kmymoney2/kmymoneyutils.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/kmymoneyutils.h')
-rw-r--r--kmymoney2/kmymoneyutils.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kmymoney2/kmymoneyutils.h b/kmymoney2/kmymoneyutils.h
index c6054e5..1587a3a 100644
--- a/kmymoney2/kmymoneyutils.h
+++ b/kmymoney2/kmymoneyutils.h
@@ -50,11 +50,11 @@ class KMyMoneyUtils
{
public:
/**
* This enum is used to describe the bits of an account type filter tqmask.
* Each bit is used to define a specific account class. Multiple classes
* can be specified by OR'ing multiple entries. The special entry @p last
* marks the left most bit in the tqmask and is used by scanners of this
* bittqmask to determine the end of processing.
*/
enum categoryTypeE {
none = 0x00, ///< no account class selected
@@ -63,7 +63,7 @@ public:
expense = 0x04, ///< expense accounts selected
income = 0x08, ///< income accounts selected
equity = 0x10, ///< equity accounts selected
- last = 0x20 ///< the leftmost bit in the tqmask
+ last = 0x20 ///< the leftmost bit in the mask
};
enum transactionTypeE {
@@ -50,11 +50,11 @@ class KMyMoneyUtils
public:
/**
- * This enum is used to describe the bits of an account type filter tqmask.
+ * This enum is used to describe the bits of an account type filter mask.
* Each bit is used to define a specific account class. Multiple classes
* can be specified by OR'ing multiple entries. The special entry @p last
@@ -50,11 +50,11 @@ class KMyMoneyUtils
* Each bit is used to define a specific account class. Multiple classes
* can be specified by OR'ing multiple entries. The special entry @p last
- * marks the left most bit in the tqmask and is used by scanners of this
- * bittqmask to determine the end of processing.
+ * marks the left most bit in the mask and is used by scanners of this
+ * bitmask to determine the end of processing.
*/
enum categoryTypeE {